ice_cal: Function to calculate Individual Conditional Expectation...

Description Usage Arguments Value Author(s)

View source: R/ice.R

Description

Function to create partial dependence plots given features and the training set

Usage

1
2
ice_cal(model, variable, fulldf, subsetdf, grid.resolution = 10,
  trim.outliers = FALSE)

Arguments

model

name of the randomForest model

variable

name of the interested feature

fulldf

full data set used to fit the random forest

subsetdf

subset of the dataset use to compute ice

grid.resolution

number of levels to be considered in the interested feature

trim.outliers

if TRUE range for the grid.resolution is computed trimming the outliers

Value

a dataframe including corresponding probability for each class

Author(s)

Thiyanga Talagala


thiyangt/explainer documentation built on July 20, 2019, 6:58 p.m.