meansd_ice: Function to calculate mean of standard deviation of ICE...

Description Usage Arguments Value Author(s)

View source: R/sd_ice.R

Description

ICE-based variable importance measure: mean of standard deviation of ICE curves

Usage

1
meansd_ice(ice_data, variable, classlabelvec, subrw, grid.resolution)

Arguments

ice_data

ice calculations for a specific variable(output of ice_cal)

variable

name of the interested feature

classlabelvec

vector of names corresponds to classlabels

subrw

number of rows in the subset of the data frame we use to calculate ice curves in ice_cal function

grid.resolution

gridresolution size used in ice_cal function

Value

a dataframe including corresponding probability for each class

Author(s)

Thiyanga Talagala


thiyangt/explainer documentation built on July 20, 2019, 6:58 p.m.