twowayinteraction: Two-way interaction plots

Description Usage Arguments Value Author(s)

View source: R/twowaypartial.R

Description

Given two features create partial two way interaction contourplots

Usage

1
2
twowayinteraction(model, variable1, variable2, fulldf, subsetdf,
  grid.resolution = 10, trim1 = FALSE, trim2 = FALSE)

Arguments

model

name of the fitted randomforest model

variable1

name of the first variable

variable2

name of the second variable

fulldf

full data set used to fit the random forest

subsetdf

subset dataset used to evaluate the fitted model

grid.resolution

number of levels to be considered in the interested features

trim1

if TRUE remove outliers of the first variable

trim2

if TRUE remove outliers of the second variable

Value

data frame containing features and pedicted probabilities

Author(s)

Thiyanga Talagala


thiyangt/explainer documentation built on July 20, 2019, 6:58 p.m.