Description Usage Arguments Value Author(s)
Function to create partial dependence plots given features and the training set
1 2 |
model |
name of the randomForest model |
variable |
name of the interested feature |
fulldf |
full data set used to fit the random forest |
subsetdf |
subset of the dataset use to compute ice |
grid.resolution |
number of levels to be considered in the interested feature |
trim.outliers |
if TRUE range for the grid.resolution is computed trimming the outliers |
a dataframe including corresponding probability for each class
Thiyanga Talagala
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.