Description Usage Arguments Value Author(s)
ICE-based variable importance measure: mean of standard deviation of ICE curves
1 | meansd_ice(ice_data, variable, classlabelvec, subrw, grid.resolution)
|
ice_data |
ice calculations for a specific variable(output of ice_cal) |
variable |
name of the interested feature |
classlabelvec |
vector of names corresponds to classlabels |
subrw |
number of rows in the subset of the data frame we use to calculate ice curves in ice_cal function |
grid.resolution |
gridresolution size used in ice_cal function |
a dataframe including corresponding probability for each class
Thiyanga Talagala
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.