Description Usage Arguments Value Author(s)
View source: R/twowaypartial.R
Given two features create partial two way interaction contourplots
1 2 | twowayinteraction(model, variable1, variable2, fulldf, subsetdf,
grid.resolution = 10, trim1 = FALSE, trim2 = FALSE)
|
model |
name of the fitted randomforest model |
variable1 |
name of the first variable |
variable2 |
name of the second variable |
fulldf |
full data set used to fit the random forest |
subsetdf |
subset dataset used to evaluate the fitted model |
grid.resolution |
number of levels to be considered in the interested features |
trim1 |
if TRUE remove outliers of the first variable |
trim2 |
if TRUE remove outliers of the second variable |
data frame containing features and pedicted probabilities
Thiyanga Talagala
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.